#!/bin/sh -x
PKG="clonezilla"
RPMBUILD="${HOME}/rpmbuild/"
SPEC_FILE="$PKG.spec"

#
[ ! -f "$SPEC_FILE" ] && echo "Can NOT find spec file $SPEC_FILE" && exit 1

# Create the changelog file
mkdir -p doc
#
[ -f "doc/ChangeLog.txt" ] && rm -f doc/ChangeLog.txt
line_begin="$(grep -n "%changelog" $SPEC_FILE | awk -F":" '{print $1}')"
line_eng="$(wc -l $SPEC_FILE | awk -F" " '{print $1}')"
lines=$(($line_eng - $line_begin))
cat <<EOF > doc/ChangeLog.txt
Clonezilla, the opensource clone system
Author: Steven Shiau <steven _at_ nchc org tw>, Blake, Kuo-Lien Huang (klhaung _at_ gmail com), H. T. Wang (c00wht00 _at_ nchc org tw), Ceasar Sun (ceasar _at_ nchc org tw), Jazz Wang (jazz _at_ nchc org tw) and Thomas Tsai (thomas _at_ nchc org tw)
License: GPL
http://clonezilla.nchc.org.tw
http://clonezilla.sf.net

EOF

tail -n $lines $SPEC_FILE >> doc/ChangeLog.txt

#
VER=`grep ^Version $SPEC_FILE |sed -e "s/\t/ /g" -e "s/ \+/ /g" |cut  -d":" -f2 |tr -d " "`
RELEASE=`grep ^Release $SPEC_FILE |sed -e "s/\t/ /g" -e "s/ \+/ /g" |cut  -d":" -f2 |tr -d " "`
echo "VER, RELEASE: $VER, $RELEASE"

TARBALL="$PKG-$VER.tar.bz2"
#check if necessary files exist...
[ -f $SPEC_FILE ] || exit 0
[ -f $TARBALL ] && rm -f $TARBALL
tar cvjf $TARBALL $PKG --exclude CVS --exclude split-ocs --exclude with-udp-cast --exclude old --exclude testing
[ -f $TARBALL ] || exit 0
#supress the tab and multi-spaces to one space
RELEASE=`grep ^Release $PKG.spec |sed -e "s/\t/ /g" -e "s/ \+/ /g" |cut  -d":" -f2 |tr -d " "`
echo "RELEASE:$RELEASE"

echo "Prepare the necessary files..."
#clean old file
[ -d ~/rpmbuild/SOURCES/$PKG-$VER ] && rm -rf ~/rpmbuild/SOURCES/$PKG-$VER
[ -d ~/rpmbuild/BUILD/$PKG-$VER ] && rm -rf ~/rpmbuild/BUILD/$PKG-$VER

mkdir -p ~/rpmbuild/SOURCES/$PKG-$VER

#clean old build rpm files
[ -f rpms/$PKG-$VER-$RELEASE.src.rpm ] && rm -f rpms/$PKG-$VER-$RELEASE.src.rpm 
[ -f rpms/$PKG-$VER-$RELEASE.i386.rpm ] && rm -f rpms/$PKG-$VER-$RELEASE.i386.rpm 

# extract the source tarball
# clean the tmp directory

# package the tar ball
cp $TARBALL ~/rpmbuild/SOURCES/$PKG-$VER/

echo "We are ready to build rpm file now..."

# build it
rpmbuild -ba $SPEC_FILE

# clean the RPMS.drbl directory
[ -d RPMS.drbl-test ] && rm -rf RPMS.drbl-test
mkdir -p RPMS.drbl-test

# cp them to directory rpms 
cp ~/rpmbuild/SRPMS/$PKG-$VER-$RELEASE.src.rpm ~/rpmbuild/RPMS/$PKG-$VER-$RELEASE.i386.rpm RPMS.drbl-test

#clean the used file
[ -d ~/rpmbuild/SOURCES/$PKG-$VER ] && rm -rf ~/rpmbuild/SOURCES/$PKG-$VER
[ -d ~/rpmbuild/BUILD/$PKG-$VER ] && rm -rf ~/rpmbuild/BUILD/$PKG-$VER
